package vishnu.builder;

import java.io.*;
import java.util.*;
import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.index.IndexWriter;


public class LuceneWrapper extends Indexer
{
    
    private static void usage()
    {
	System.out.println("java LucenceWrapper -i InputDirectory \n -o OutputDirectory \n -c CollectionName");
    }
    
    
    public static void main(String[] args)
    {
	String in = null;
	String out = null;
	String coll = null;

	if( args.length == 0 ){
	    usage();
	    System.exit(0);
	}
	
	int a = 0;
	while( a < args.length ){
	    if( args[a].equals("-i") )
		in = args[++a];
	    if( args[a].equals("-o") )
		out = args[++a];
	    if( args[a].equals("-c") )
		coll = args[++a];
	    a++;
	}
	if (out==null || in==null|| coll==null) {
	    usage();
	    System.exit(0);
	}
	if (!out.endsWith(File.separator)) {
	    out += File.separator;
	}
	if (!in.endsWith(File.separator)) {
	    in += File.separator;
	}

	LuceneWrapper luc = new LuceneWrapper();
	
	out = out + "luc_index";
	luc.setCollectionName(coll);
        luc.setOutputDirectory(out);
	luc.setInputDirectory(in);
	luc.startIndexing();
    }
    
    
    public LuceneWrapper()
    {
	super("Lucene Indexer");
    }
    
    public void startIndexing() {
	initialize();
	try {
	    IndexWriter writer = new IndexWriter(outputDir, new StandardAnalyzer(), true);
	    // this is a bit of a hack putting import here
	    indexFiles(writer, new File(inputDir), "import/");
	    writer.optimize();
	    writer.close();
	} catch (Exception e) {
	    System.err.println("Error creating the Lucene index: "+e);
	    System.exit(0);
	}

    }

    private void indexFiles(IndexWriter writer, File input_dir, String current_path) {
	File [] doc_list = input_dir.listFiles();
	for (int i=0; i<doc_list.length; i++) {
	    File f = doc_list[i];
	    if (f.isDirectory()) {
		indexFiles(writer, f, current_path+f.getName()+File.separator);
	    } else {
		try {
		    writer.addDocument(FileDocument.Document(f, current_path+f.getName()));	
		} catch (Exception e) {
		    System.err.println("Error indexing document "+current_path+f.getName()+": "+e);
		}
	    }
	}

    }

	
    public void startIndexingOld()
    {
	
	if( inputDir == null || outputDir == null ){
	    usage();
	    System.exit(0);
	}
	
	
	/**** check if output directory exists, if not create it ****/
	
	
        File f = new File(outputDir);
        if( !f.exists() ){
            System.out.println("Creating output directory..");
	    
            StringTokenizer strt = new StringTokenizer(outputDir,"/");
            String d = "";
            while(strt.hasMoreTokens()){
                String str = strt.nextToken();
                if( str.indexOf(".") == -1 ){
		    d += "/" + str;
		    if( !(new File(d)).exists() ){
			try{
			    Runtime rt = Runtime.getRuntime();
			    Process proc = rt.exec("mkdir " + d);
			    int exitVal = proc.waitFor();
			}catch(Exception ex){ex.printStackTrace();}
		    }
		}
	    }
        }	
	
	File docList = new File(inputDir + "/docs.lst");
	
	if (!docList.exists()){
	    System.out.println("No documents found");
	    System.exit(0);
	}
	
	Vector docs = new Vector();
	
	try{
            BufferedReader dis = new BufferedReader(new InputStreamReader(new FileInputStream(docList)));
	    String line = "";
            while( (line=dis.readLine())!=null ){
		docs.addElement(new String(inputDir+"/" + line));
	    }
            dis.close();
	} catch(IOException ex){ex.printStackTrace();}
	
	try{
	    
	    IndexWriter writer = new IndexWriter(outputDir, new StandardAnalyzer(), true);
	    
	    for( int i = 0; i < docs.size(); i++ ){
		File file = new File((String)docs.elementAt(i));		
		//writer.addDocument(FileDocument.Document(file));
	    }
	    writer.optimize();
	    writer.close();
        }catch(Exception ex){ex.printStackTrace();}
    }
}

